/* 
   Copyright (C) 2009, 2010, 2011, 2012 German A. Arias <german@xelalug.org>

   This file is part of FísicaLab application

   FísicaLab is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 3 of the License, or (at your option) any later version.
 
   This application is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.
 
   You should have received a copy of the GNU General Public
   License along with this library; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA.
*/

#import <stdlib.h>
#import <stdio.h>
#import <math.h>
#import <gsl/gsl_vector.h>
#import <gsl/gsl_multiroots.h>
#import <gsl/gsl_rng.h>
#import "estaticaPuntual.h"

static int varG ;
static double gravedadDat ;
static NSMutableDictionary *diccionario ;
static NSMutableArray *variables, *fuerObj, *tipoFuer, *codObjetos, *codOtros ;
static NSString *gravedadVar ;

int valoresEstatPunt (const gsl_vector *, void *, gsl_vector *);

struct parametros
{
  double a;
  double b;
};

int sis_estatica (const gsl_vector *variables, void *params, gsl_vector *funciones)
{
  valoresEstatPunt (variables, params, funciones);  
  return GSL_SUCCESS;
}

int valoresEstatPunt (const gsl_vector *vars, void *p, gsl_vector *func)
{
  int gIndice, codigoFuer = 0 ;
  int nEcu = 0 ;
  double gf ;
  NSNumber *objeto ;
  NSEnumerator *enumerador;
  
  if(varG == 1)
    {
      gIndice = [variables indexOfObject: gravedadVar] ;
      gf = gsl_vector_get (vars, gIndice) ;   
    }
  else
    {
      if(varG == 2)
	{
          gf = gravedadDat ;
	}
      else
	{
          gf = 0 ;
	}
    }
  
  enumerador = [codObjetos objectEnumerator] ;
  
  while((objeto = [enumerador nextObject]))
    {
      NSNumber *tipo = [[diccionario objectForKey: objeto] objectForKey: @"Tipo"] ;
      NSMutableArray *dat = [[diccionario objectForKey: objeto] objectForKey: @"Valores"] ;
      
      switch([tipo intValue])
	{
	case 51:
	  {
	    double peso, masa ;
            
	    if(![variables containsObject: [[dat objectAtIndex: 0] stringByTrimmingSpaces] ])
	      {
		masa = [[dat objectAtIndex: 0] doubleValue] ;
	      }
	    else
	      {
		int k = [variables indexOfObject: [[dat objectAtIndex: 0] stringByTrimmingSpaces]] ;
		masa = gsl_vector_get (vars, k) ;
	      }
	    
	    peso = masa*gf ;
            
	    if([[tipoFuer objectAtIndex: codigoFuer] intValue] == 3)
	      {
		double signo ; 
		double fuerza = 0 ;
		NSNumber *codFuerObj ;
		NSEnumerator *objFuer;
		fuerza = -1*peso;
		objFuer = [[fuerObj objectAtIndex: codigoFuer] objectEnumerator] ;
                
		while((codFuerObj = [objFuer nextObject]))
		  {
		    int t = [[[diccionario objectForKey: codFuerObj] objectForKey: @"Tipo"] intValue] ;
                    
		    if( t == 62 )
		      { signo = 1; }
		    else
		      { signo = - 1; }   
		    
		    if(![variables containsObject: [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces] ])
		      {
			fuerza = fuerza + signo*[[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] doubleValue] ;
		      }
		    else
		      {
			int k = [variables indexOfObject: [[[[diccionario objectForKey:  codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces]] ;
			fuerza = fuerza + signo*(gsl_vector_get (vars, k)) ;
		      }
		  }
		
		//Se establece la ecuacion
		gsl_vector_set (func, nEcu, fuerza);
		
		nEcu = nEcu + 1 ;
	      }
	    else
	      {
		double signox, signoy ; 
		double fuerzax = 0;
		double fuerzay = 0;
		NSNumber *codFuerObj ;
		NSEnumerator *objFuer;
		fuerzay = -1*peso;
		objFuer = [[fuerObj objectAtIndex: codigoFuer] objectEnumerator] ;
                
		while((codFuerObj = [objFuer nextObject]))
		  {
		    int t = [[[diccionario objectForKey: codFuerObj] objectForKey: @"Tipo"] intValue] ;
                    
		    switch(t)
		      {
		      case 60:
		      case 61:
			{
			  if(t == 60)
			    { signox = 1; }
			  else
			    { signox = - 1; }
			  
			  if(![variables containsObject: [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces] ])
			    {
			      fuerzax = fuerzax + signox*[[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] doubleValue] ;
			    }
			  else
			    {
			      int k = [variables indexOfObject: [[[[diccionario objectForKey:  codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces]] ;
			      fuerzax = fuerzax + signox*(gsl_vector_get (vars, k)) ;
			    }
			}
			break;
		      case 62:
		      case 63:
			{
			  if(t == 62)
			    { signoy = 1; }
			  else
			    { signoy = - 1; }
			  
			  if(![variables containsObject: [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces] ])
			    {
			      fuerzay = fuerzay + signoy*[[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] doubleValue] ;
			    }
			  else
			    {
			      int k = [variables indexOfObject: [[[[diccionario objectForKey:  codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces]] ;
			      fuerzay = fuerzay + signoy*(gsl_vector_get (vars, k)) ;
			    }
			}
			break;
		      case 56 ... 59:
			{
			  double ang ;
                          
			  if( (t == 56) || (t == 59) )
			    { signox = 1; }
			  else
			    { signox = - 1; }
			  
			  if( (t == 56) || (t == 58) )
			    { signoy = 1; }
			  else
			    { signoy = - 1; }
			  
			  if(![variables containsObject: [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 1] stringByTrimmingSpaces] ])
			    {
			      ang = [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 1] doubleValue] ;
			    }
			  else
			    {
			      int k = [variables indexOfObject: [[[[diccionario objectForKey:  codFuerObj] objectForKey: @"Valores"] objectAtIndex: 1] stringByTrimmingSpaces]] ;
			      ang = gsl_vector_get (vars, k) ;
			    }
			  
			  if(![variables containsObject: [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces] ])
			    {
			      fuerzax = fuerzax + signox*[[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] doubleValue]*cos(M_PI*ang/180) ;
			      fuerzay = fuerzay + signoy*[[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] doubleValue]*sin(M_PI*ang/180) ;
			    }
			  else
			    {
			      int k = [variables indexOfObject: [[[[diccionario objectForKey:  codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces]] ;
			      fuerzax = fuerzax + signox*(gsl_vector_get (vars, k))*cos(M_PI*ang/180) ;
			      fuerzay = fuerzay + signoy*(gsl_vector_get (vars, k))*sin(M_PI*ang/180) ;
			    }
			}
			break;
		      case 68:
		      case 69:
			{
			  double u;
			  
			  if(t == 68)
			    { signox = 1; }
			  else
			    { signox = - 1; }

			  if (![variables containsObject: [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 1] stringByTrimmingSpaces] ])
			    {
			      u = [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 1] doubleValue];
			    }
			  else
			    {
			      int k = [variables indexOfObject: [[[[diccionario objectForKey:  codFuerObj] objectForKey: @"Valores"] objectAtIndex: 1] stringByTrimmingSpaces]] ;
			      u = gsl_vector_get (vars, k);
			    }
			  
			  if(![variables containsObject: [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces] ])
			    {
			      fuerzax = fuerzax + signox*u*[[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] doubleValue] ;
			    }
			  else
			    {
			      int k = [variables indexOfObject: [[[[diccionario objectForKey:  codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces]] ;
			      fuerzax = fuerzax + signox*u*(gsl_vector_get (vars, k)) ;
			    }
			}
			break;
		      case 70:
		      case 71:
			{
			  double u;

			  if(t == 70)
			    { signoy = 1; }
			  else
			    { signoy = - 1; }

			  if (![variables containsObject: [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 1] stringByTrimmingSpaces] ])
			    {
			      u = [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 1] doubleValue];
			    }
			  else
			    {
			      int k = [variables indexOfObject: [[[[diccionario objectForKey:  codFuerObj] objectForKey: @"Valores"] objectAtIndex: 1] stringByTrimmingSpaces]] ;
			      u = gsl_vector_get (vars, k);
			    }
			  
			  if(![variables containsObject: [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces] ])
			    {
			      fuerzay = fuerzay + signoy*u*[[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] doubleValue] ;
			    }
			  else
			    {
			      int k = [variables indexOfObject: [[[[diccionario objectForKey:  codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces]] ;
			      fuerzay = fuerzay + signoy*u*(gsl_vector_get (vars, k)) ;
			    }
			}
			break;
		      }
		  }
		
		//Se establecen las ecuaciones
		gsl_vector_set (func, nEcu, fuerzax);
		gsl_vector_set (func, nEcu + 1, fuerzay);
		
		nEcu = nEcu + 2 ;
	      }
	  }
	  break;
	case 52:
	  {
	    double signox = 0, signoy = 0; 
	    double fuerzax = 0;
	    double fuerzay = 0;
	    double masa, ang ;
	    NSNumber *codFuerObj ;
	    NSEnumerator *objFuer;
            
	    if(![variables containsObject: [[dat objectAtIndex: 1] stringByTrimmingSpaces] ])
	      {
		ang = [[dat objectAtIndex: 1] doubleValue] ;
	      }
	    else
	      {
		int k = [variables indexOfObject: [[dat objectAtIndex: 1] stringByTrimmingSpaces]] ;
		ang = gsl_vector_get (vars, k) ;
	      }
	    
	    if(![variables containsObject: [[dat objectAtIndex: 0] stringByTrimmingSpaces] ])
	      {
		masa = [[dat objectAtIndex: 0] doubleValue] ;
	      }
	    else
	      {
		int k = [variables indexOfObject: [[dat objectAtIndex: 0] stringByTrimmingSpaces]] ;
		masa = gsl_vector_get (vars, k) ;
	      }
	    
	    fuerzax = -1*masa*sin(M_PI*ang/180)*gf ;
	    fuerzay = -1*masa*cos(M_PI*ang/180)*gf ;
	    objFuer = [[fuerObj objectAtIndex: codigoFuer] objectEnumerator] ;
            
	    while((codFuerObj = [objFuer nextObject]))
	      {
		int t = [[[diccionario objectForKey: codFuerObj] objectForKey: @"Tipo"] intValue] ;
                
		switch(t)
		  {
		  case 60:
		  case 61:
		    {
		      if(t == 60)
			{ signox = 1;
			  signoy = - 1; }
		      else
			{ signox = - 1; 
			  signoy = 1; }
		      
		      if(![variables containsObject: [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces] ])
			{
			  fuerzax = fuerzax + signox*[[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] doubleValue]*cos(M_PI*ang/180) ;
			  fuerzay = fuerzay + signoy*[[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] doubleValue]*sin(M_PI*ang/180) ;
			}
		      else
			{
			  int k = [variables indexOfObject: [[[[diccionario objectForKey:  codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces]] ;
			  fuerzax = fuerzax + signox*(gsl_vector_get (vars, k))*cos(M_PI*ang/180) ;
			  fuerzay = fuerzay + signoy*(gsl_vector_get (vars, k))*sin(M_PI*ang/180) ;
			}
		    }
		    break;
		  case 62:
		  case 63:
		    {
		      if(t == 62)
			{ signox = 1;
			  signoy = 1; }
		      else
			{ signox = - 1;
			  signoy = - 1; }
		      
		      if(![variables containsObject: [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces] ])
			{
			  fuerzax = fuerzax + signox*[[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] doubleValue]*sin(M_PI*ang/180) ;
			  fuerzay = fuerzay + signoy*[[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] doubleValue]*cos(M_PI*ang/180) ;
			}
		      else
			{
			  int k = [variables indexOfObject: [[[[diccionario objectForKey:  codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces]] ;
			  fuerzax = fuerzax + signox*(gsl_vector_get (vars, k))*sin(M_PI*ang/180) ;
			  fuerzay = fuerzay + signoy*(gsl_vector_get (vars, k))*cos(M_PI*ang/180) ;
			}
		    }
		    break;
		  case 56 ... 59:
		    {
		      double angf = 0, angr = 0;
                      
		      if(![variables containsObject: [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 1] stringByTrimmingSpaces] ])
			{
			  angf = [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 1] doubleValue] ;
			}
		      else
			{
			  int k = [variables indexOfObject: [[[[diccionario objectForKey:  codFuerObj] objectForKey: @"Valores"] objectAtIndex: 1] stringByTrimmingSpaces]] ;
			  angf = gsl_vector_get (vars, k) ;
			}
		      
		      if (t == 56)
			{
			  signox = 1;
			  signoy = 1; 
			  angr = angf - ang;
			}
		      
		      if (t == 57)
			{
			  signox = - 1;
			  signoy = 1;
			  angr = ang - angf;
			}
		      
		      if (t == 58)
			{
			  signoy = 1;
			  signox = -1;
			  angr = angf + ang;
			}
		      
		      if (t == 59)
			{
			  signoy = - 1;
			  signox = 1; 
			  angr = angf + ang;
			}
		      
		      if(![variables containsObject: [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces] ])
			{
			  fuerzax = fuerzax + signox*[[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] doubleValue]*cos(M_PI*angr/180) ;
			  fuerzay = fuerzay + signoy*[[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] doubleValue]*sin(M_PI*angr/180) ;
			}
		      else
			{
			  int k = [variables indexOfObject: [[[[diccionario objectForKey:  codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces]] ;
			  fuerzax = fuerzax + signox*(gsl_vector_get (vars, k))*cos(M_PI*angr/180) ;
			  fuerzay = fuerzay + signoy*(gsl_vector_get (vars, k))*sin(M_PI*angr/180) ;
			}
		    }
		    break;
		  case 64:
		  case 65:
		    {
		      double u;

		      if(t == 64)
			{ signox = 1; }
		      else
			{ signox = - 1; }

		      if (![variables containsObject: [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 1] stringByTrimmingSpaces] ])
			{
			  u = [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 1] doubleValue];
			}
		      else
			{
			  int k = [variables indexOfObject: [[[[diccionario objectForKey:  codFuerObj] objectForKey: @"Valores"] objectAtIndex: 1] stringByTrimmingSpaces]] ;
			  u = gsl_vector_get (vars, k);
			}
		      
		      if(![variables containsObject: [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces] ])
			{
			  fuerzax = fuerzax + signox*u*[[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] doubleValue] ;
			}
		      else
			{
			  int k = [variables indexOfObject: [[[[diccionario objectForKey:  codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces]] ;
			  fuerzax = fuerzax + signox*u*(gsl_vector_get (vars, k)) ;
			}
		    }
		    break;
		  }
	      }
	    
	    //Se establecen las ecuaciones
	    gsl_vector_set (func, nEcu, fuerzax);
	    gsl_vector_set (func, nEcu + 1, fuerzay);
	    
	    nEcu = nEcu + 2 ;
	  }
	  break;
	case 53:
	  {
	    double signox = 0, signoy = 0; 
	    double fuerzax = 0;
	    double fuerzay = 0;
	    double masa, ang ;
	    NSNumber *codFuerObj ;
	    NSEnumerator *objFuer;
            
	    if(![variables containsObject: [[dat objectAtIndex: 1] stringByTrimmingSpaces] ])
	      {
		ang = [[dat objectAtIndex: 1] doubleValue] ;
	      }
	    else
	      {
		int k = [variables indexOfObject: [[dat objectAtIndex: 1] stringByTrimmingSpaces]] ;
		ang = gsl_vector_get (vars, k) ;
	      }
	    
	    if(![variables containsObject: [[dat objectAtIndex: 0] stringByTrimmingSpaces] ])
	      {
		masa = [[dat objectAtIndex: 0] doubleValue] ;
	      }
	    else
	      {
		int k = [variables indexOfObject: [[dat objectAtIndex: 0] stringByTrimmingSpaces]] ;
		masa = gsl_vector_get (vars, k) ;
	      }
	    
	    fuerzax = -1*masa*sin(M_PI*ang/180)*gf ;
	    fuerzay = -1*masa*cos(M_PI*ang/180)*gf ;
	    objFuer = [[fuerObj objectAtIndex: codigoFuer] objectEnumerator] ;
            
	    while((codFuerObj = [objFuer nextObject]))
	      {
		int t = [[[diccionario objectForKey: codFuerObj] objectForKey: @"Tipo"] intValue] ;
                
		switch(t)
		  {
		  case 60:
		  case 61:
		    {
		      if(t == 61)
			{ signox = 1;
			  signoy = - 1; }
		      else
			{ signox = - 1; 
			  signoy = 1; }
		      
		      if(![variables containsObject: [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces] ])
			{
			  fuerzax = fuerzax + signox*[[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] doubleValue]*cos(M_PI*ang/180) ;
			  fuerzay = fuerzay + signoy*[[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] doubleValue]*sin(M_PI*ang/180) ;
			}
		      else
			{
			  int k = [variables indexOfObject: [[[[diccionario objectForKey:  codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces]] ;
			  fuerzax = fuerzax + signox*(gsl_vector_get (vars, k))*cos(M_PI*ang/180) ;
			  fuerzay = fuerzay + signoy*(gsl_vector_get (vars, k))*sin(M_PI*ang/180) ;
			}
		    }
		    break;
		  case 62:
		  case 63:
		    {
		      if(t == 62)
			{ signox = 1;
			  signoy = 1; }
		      else
			{ signox = - 1;
			  signoy = - 1; }
		      
		      if(![variables containsObject: [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces] ])
			{
			  fuerzax = fuerzax + signox*[[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] doubleValue]*sin(M_PI*ang/180) ;
			  fuerzay = fuerzay + signoy*[[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] doubleValue]*cos(M_PI*ang/180) ;
			}
		      else
			{
			  int k = [variables indexOfObject: [[[[diccionario objectForKey:  codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces]] ;
			  fuerzax = fuerzax + signox*(gsl_vector_get (vars, k))*sin(M_PI*ang/180) ;
			  fuerzay = fuerzay + signoy*(gsl_vector_get (vars, k))*cos(M_PI*ang/180) ;
			}
		    }
		    break;
		  case 56 ... 59:
		    {
		      double angf = 0, angr = 0;
                      
		      if(![variables containsObject: [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 1] stringByTrimmingSpaces] ])
			{
			  angf = [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 1] doubleValue] ;
			}
		      else
			{
			  int k = [variables indexOfObject: [[[[diccionario objectForKey:  codFuerObj] objectForKey: @"Valores"] objectAtIndex: 1] stringByTrimmingSpaces]] ;
			  angf = gsl_vector_get (vars, k) ;
			}
		      
		      if(t == 56)
			{
			  signoy = 1;
			  signox = -1;
			  angr = ang + angf;
			}
		      
		      if(t == 57)
			{
			  signoy = - 1;
			  signox = 1;
			  angr = angf + ang;
			}
		      
		      if(t == 58)
			{
			  signox = 1;
			  signoy = 1;
			  angr = angf - ang;
			}
		      
		      if(t == 59)
			{
			  signox = - 1;
			  signoy = 1;
			  angr = ang - angf;
			}
		      
		      if(![variables containsObject: [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces] ])
			{
			  fuerzax = fuerzax + signox*[[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] doubleValue]*cos(M_PI*angr/180) ;
			  fuerzay = fuerzay + signoy*[[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] doubleValue]*sin(M_PI*angr/180) ;
			}
		      else
			{
			  int k = [variables indexOfObject: [[[[diccionario objectForKey:  codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces]] ;
			  fuerzax = fuerzax + signox*(gsl_vector_get (vars, k))*cos(M_PI*angr/180) ;
			  fuerzay = fuerzay + signoy*(gsl_vector_get (vars, k))*sin(M_PI*angr/180) ;
			}
		    }
		    break;
		  case 66:
		  case 67:
		    {
		      double u;

		      if(t == 66)
			{ signox = 1; }
		      else
			{ signox = - 1; }

		      if (![variables containsObject: [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 1] stringByTrimmingSpaces] ])
			{
			  u = [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 1] doubleValue];
			}
		      else
			{
			  int k = [variables indexOfObject: [[[[diccionario objectForKey:  codFuerObj] objectForKey: @"Valores"] objectAtIndex: 1] stringByTrimmingSpaces]] ;
			  u = gsl_vector_get (vars, k);
			}
		      
		      if(![variables containsObject: [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces] ])
			{
			  fuerzax = fuerzax + signox*u*[[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] doubleValue] ;
			}
		      else
			{
			  int k = [variables indexOfObject: [[[[diccionario objectForKey:  codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces]] ;
			  fuerzax = fuerzax + signox*u*(gsl_vector_get (vars, k)) ;
			}
		    }
		    break;
		  }
	      }
            
	    //Se establecen las ecuaciones
	    gsl_vector_set (func, nEcu, fuerzax);
	    gsl_vector_set (func, nEcu + 1, fuerzay);
	    
	    nEcu = nEcu + 2 ;
	  }
	  break;
	case 54:
	  {
	    
	    if( ([[tipoFuer objectAtIndex: codigoFuer] intValue] == 2) || ([[tipoFuer objectAtIndex: codigoFuer] intValue] == 3) )
	      {
		double signo ;
		double fuerza = 0;
		NSNumber *codFuerObj ;
		NSEnumerator *objFuer = [[fuerObj objectAtIndex: codigoFuer] objectEnumerator] ;
                
		while((codFuerObj = [objFuer nextObject]))
		  {
		    int t = [[[diccionario objectForKey: codFuerObj] objectForKey: @"Tipo"] intValue] ;
                    
		    if( (t == 60) || (t == 62) )
		      { signo = 1; }
		    else
		      { signo = - 1; }   
		    
		    if(![variables containsObject: [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces] ])
		      {
			fuerza = fuerza + signo*[[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] doubleValue] ;
		      }
		    else
		      {
			int k = [variables indexOfObject: [[[[diccionario objectForKey:  codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces]] ;
			fuerza = fuerza + signo*(gsl_vector_get (vars, k)) ;
		      }
		  }
		
		//Se establece la ecuacion
		gsl_vector_set (func, nEcu, fuerza);
		
		nEcu = nEcu + 1 ;
	      }
	    else
	      {
		double signox, signoy ;  
		double fuerzax = 0;
		double fuerzay = 0;
		NSNumber *codFuerObj ;
		NSEnumerator *objFuer = [[fuerObj objectAtIndex: codigoFuer] objectEnumerator] ;
                
		while((codFuerObj = [objFuer nextObject]))
		  {
		    int t = [[[diccionario objectForKey: codFuerObj] objectForKey: @"Tipo"] intValue] ;
                    
		    switch(t)
		      {
		      case 60:
		      case 61:
			{
			  if(t == 60)
			    { signox = 1; }
			  else
			    { signox = - 1; }
			  
			  if(![variables containsObject: [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces] ])
			    {
			      fuerzax = fuerzax + signox*[[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] doubleValue] ;
			    }
			  else
			    {
			      int k = [variables indexOfObject: [[[[diccionario objectForKey:  codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces]] ;
			      fuerzax = fuerzax + signox*(gsl_vector_get (vars, k)) ;
			    }
			}
			break;
		      case 62:
		      case 63:
			{
			  if(t == 62)
			    { signoy = 1; }
			  else
			    { signoy = - 1; }
			  
			  if(![variables containsObject: [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces] ])
			    {
			      fuerzay = fuerzay + signoy*[[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] doubleValue] ;
			    }
			  else
			    {
			      int k = [variables indexOfObject: [[[[diccionario objectForKey:  codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces]] ;
			      fuerzay = fuerzay + signoy*(gsl_vector_get (vars, k)) ;
			    }
			}
			break;
		      case 56 ... 59:
			{
			  double ang ;
                          
			  if( (t == 56) || (t == 59) )
			    { signox = 1; }
			  else
			    { signox = - 1; }
			  
			  if( (t == 56) || (t == 58) )
			    { signoy = 1; }
			  else
			    { signoy = - 1; }
			  
			  if(![variables containsObject: [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 1] stringByTrimmingSpaces] ])
			    {
			      ang = [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 1] doubleValue] ;
			    }
			  else
			    {
			      int k = [variables indexOfObject: [[[[diccionario objectForKey:  codFuerObj] objectForKey: @"Valores"] objectAtIndex: 1] stringByTrimmingSpaces]] ;
			      ang = gsl_vector_get (vars, k) ;
			    }
			  
			  if(![variables containsObject: [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces] ])
			    {
			      fuerzax = fuerzax + signox*[[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] doubleValue]*cos(M_PI*ang/180) ;
			      fuerzay = fuerzay + signoy*[[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] doubleValue]*sin(M_PI*ang/180) ;
			    }
			  else
			    {
			      int k = [variables indexOfObject: [[[[diccionario objectForKey:  codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces]] ;
			      fuerzax = fuerzax + signox*(gsl_vector_get (vars, k))*cos(M_PI*ang/180) ;
			      fuerzay = fuerzay + signoy*(gsl_vector_get (vars, k))*sin(M_PI*ang/180) ;
			    }
			}
			break;
		      }
		  }
		
		//Se establecen las ecuaciones
		gsl_vector_set (func, nEcu, fuerzax);
		gsl_vector_set (func, nEcu + 1, fuerzay);
		
		nEcu = nEcu + 2 ;
	      }
	  }
	  break;
	case 55:
	  {
	    if( ([[tipoFuer objectAtIndex: codigoFuer] intValue] == 2) || ([[tipoFuer objectAtIndex: codigoFuer] intValue] == 3) )
	      {
		double signo = 0;
		double fuerza = 0;
		NSNumber *codFuerObj ;
		NSEnumerator *objFuer = [[fuerObj objectAtIndex: codigoFuer] objectEnumerator] ;
                
		while((codFuerObj = [objFuer nextObject]))
		  {
		    int t = [[[diccionario objectForKey: codFuerObj] objectForKey: @"Tipo"] intValue] ;
                    
		    switch(t)
		      {
		      case 60:
		      case 61:
		      case 62:
		      case 63:
			{   
			  if( (t == 60) || (t == 62) )
			    { signo = 1; }
			  else
			    { signo = - 1; }   
			  
			  if(![variables containsObject: [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces] ])
			    {
			      fuerza = fuerza + signo*[[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] doubleValue] ;
			    }
			  else
			    {
			      int k = [variables indexOfObject: [[[[diccionario objectForKey:  codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces]] ;
			      fuerza = fuerza + signo*(gsl_vector_get (vars, k)) ;
			    }
			}
			break;
		      case 73:
		      case 74:
			{
			  if(![variables containsObject: [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces] ])
			    {
			      fuerza = fuerza - signo*[[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] doubleValue] ;
			    }
			  else
			    {
			      int k = [variables indexOfObject: [[[[diccionario objectForKey:  codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces]] ;
			      fuerza = fuerza - signo*(gsl_vector_get (vars, k)) ;
			    }
			}
			break;
		      }
		  }
		
		//Se establece la ecuacion
		gsl_vector_set (func, nEcu, fuerza);
		
		nEcu = nEcu + 1 ;
	      }
	    else
	      {
		double signox, signoy ; 
		double fuerzax = 0;
		double fuerzay = 0;
		NSNumber *codFuerObj ;
		NSEnumerator *objFuer = [[fuerObj objectAtIndex: codigoFuer] objectEnumerator] ;
                
		while((codFuerObj = [objFuer nextObject]))
		  {
		    int t = [[[diccionario objectForKey: codFuerObj] objectForKey: @"Tipo"] intValue] ;
                    
		    switch(t)
		      {
		      case 60:
		      case 61:
			{
			  if(t == 60)
			    { signox = 1; }
			  else
			    { signox = - 1; }
			  
			  if(![variables containsObject: [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces] ])
			    {
			      fuerzax = fuerzax + signox*[[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] doubleValue] ;
			    }
			  else
			    {
			      int k = [variables indexOfObject: [[[[diccionario objectForKey:  codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces]] ;
			      fuerzax = fuerzax + signox*(gsl_vector_get (vars, k)) ;
			    }
			}
			break;
		      case 62:
		      case 63:
			{
			  if(t == 62)
			    { signoy = 1; }
			  else
			    { signoy = - 1; }
			  
			  if(![variables containsObject: [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces] ])
			    {
			      fuerzay = fuerzay + signoy*[[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] doubleValue] ;
			    }
			  else
			    {
			      int k = [variables indexOfObject: [[[[diccionario objectForKey:  codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces]] ;
			      fuerzay = fuerzay + signoy*(gsl_vector_get (vars, k)) ;
			    }
			}
			break;
		      case 56 ... 59:
			{
			  double ang ;
                          
			  if( (t == 56) || (t == 59) )
			    { signox = 1; }
			  else
			    { signox = - 1; }
			  
			  if( (t == 56) || (t == 58) )
			    { signoy = 1; }
			  else
			    { signoy = - 1; }
			  
			  if(![variables containsObject: [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 1] stringByTrimmingSpaces] ])
			    {
			      ang = [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 1] doubleValue] ;
			    }
			  else
			    {
			      int k = [variables indexOfObject: [[[[diccionario objectForKey:  codFuerObj] objectForKey: @"Valores"] objectAtIndex: 1] stringByTrimmingSpaces]] ;
			      ang = gsl_vector_get (vars, k) ;
			    }
			  
			  if(![variables containsObject: [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces] ])
			    {
			      fuerzax = fuerzax + signox*[[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] doubleValue]*cos(M_PI*ang/180) ;
			      fuerzay = fuerzay + signoy*[[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] doubleValue]*sin(M_PI*ang/180) ;
			    }
			  else
			    {
			      int k = [variables indexOfObject: [[[[diccionario objectForKey:  codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces]] ;
			      fuerzax = fuerzax + signox*(gsl_vector_get (vars, k))*cos(M_PI*ang/180) ;
			      fuerzay = fuerzay + signoy*(gsl_vector_get (vars, k))*sin(M_PI*ang/180) ;
			    }
			}
			break;
		      case 72:
			{
			  double ang ;
                          
			  if(![variables containsObject: [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 1] stringByTrimmingSpaces] ])
			    {
			      ang = [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 1] doubleValue] ;
			    }
			  else
			    {
			      int k = [variables indexOfObject: [[[[diccionario objectForKey:  codFuerObj] objectForKey: @"Valores"] objectAtIndex: 1] stringByTrimmingSpaces]] ;
			      ang = gsl_vector_get (vars, k) ;
			    }
			  
			  if(![variables containsObject: [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces] ])
			    {
			      fuerzax = fuerzax - [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] doubleValue]*cos(M_PI*ang/180) ;
			      fuerzay = fuerzay - [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] doubleValue]*sin(M_PI*ang/180) ;
			    }
			  else
			    {
			      int k = [variables indexOfObject: [[[[diccionario objectForKey:  codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces]] ;
			      fuerzax = fuerzax - (gsl_vector_get (vars, k))*cos(M_PI*ang/180) ;
			      fuerzay = fuerzay - (gsl_vector_get (vars, k))*sin(M_PI*ang/180) ;
			    }
			}
			break;
		      }
		  }
		
		//Se establecen las ecuaciones
		gsl_vector_set (func, nEcu, fuerzax);
		gsl_vector_set (func, nEcu + 1, fuerzay);
		
		nEcu = nEcu + 2 ;
	      }
	  }
	  break;
	case 75 ... 78:
	  {
	    int posFuer, t;
	    double signo = 0; 
	    double kr, d, fuerza = 0 ;
	    NSNumber *codFuerObj = [[fuerObj objectAtIndex: codigoFuer] objectAtIndex: 0] ;
	    
	    if([[tipoFuer objectAtIndex: codigoFuer] intValue] == 4)
	      {
		posFuer = 1 ;
	      }
	    else
	      {
		posFuer = -1 ;
	      }
	    
	    if(![variables containsObject: [[dat objectAtIndex: 0] stringByTrimmingSpaces] ])
	      {
		kr = [[dat objectAtIndex: 0] doubleValue] ;
	      }
	    else
	      {
		int k = [variables indexOfObject: [[dat objectAtIndex: 0] stringByTrimmingSpaces]] ;
		kr = gsl_vector_get (vars, k) ;
	      }
	    
	    if(![variables containsObject: [[dat objectAtIndex: 1] stringByTrimmingSpaces] ])
	      {
		d = [[dat objectAtIndex: 1] doubleValue] ;
	      }
	    else
	      {
		int k = [variables indexOfObject: [[dat objectAtIndex: 1] stringByTrimmingSpaces]] ;
		d = gsl_vector_get (vars, k) ;
	      }
	    
	    t = [[[diccionario objectForKey: codFuerObj] objectForKey: @"Tipo"] intValue] ;
            
	    switch(t)
	      {
	      case 56:
	      case 58:
	      case 61:
	      case 62:
		{
		  signo = 1 ;
		}
		break;
	      case 57:
	      case 59:
	      case 60:
	      case 63:
		{
		  signo = -1 ;
		}
		break;
	      }
	    
	    if(![variables containsObject: [[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces] ])
	      {
		fuerza = signo*posFuer*[[[[diccionario objectForKey: codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] doubleValue] ;
	      }
	    else
	      {
		int k = [variables indexOfObject: [[[[diccionario objectForKey:  codFuerObj] objectForKey: @"Valores"] objectAtIndex: 0] stringByTrimmingSpaces]] ;
		fuerza = signo*posFuer*(gsl_vector_get (vars, k)) ;
	      }
	    
	    //Se establece la ecuacion
	    gsl_vector_set (func, nEcu, kr*d - fuerza);
	    
	    nEcu = nEcu + 1 ;
	  }
	  break;                   
	}
      codigoFuer = codigoFuer + 1 ;
    }


  enumerador = [codOtros objectEnumerator];
  while((objeto = [enumerador nextObject]))
    {
      NSNumber *tipo = [[diccionario objectForKey: objeto] objectForKey: @"Tipo"] ;
      NSMutableArray *dat = [[diccionario objectForKey: objeto] objectForKey: @"Valores"];

      switch([tipo intValue])
	{
	case 79:
	  {
	    int k;
	    double a1, a2;

	    k = [variables indexOfObject: [[dat objectAtIndex: 0] stringByTrimmingSpaces]];
	    a1 = gsl_vector_get (vars, k);
	    
	    k = [variables indexOfObject: [[dat objectAtIndex: 1] stringByTrimmingSpaces]];
	    a2 = gsl_vector_get (vars, k);
	    
	    //Set the equation
	    gsl_vector_set (func, nEcu, sin(M_PI*a1/180) - cos(M_PI*a2/180));
	    
	    nEcu = nEcu + 1;
	  }
	  break;
	}
    }

  return 0 ;       
}

@interface estaticaPuntual (Private)
- (void) crearSistema;
@end

@implementation estaticaPuntual (Private)
- (void) crearSistema
{
  int aumento = 1 ;
  double nuevoValor ;
  BOOL continuar ;
  
  const gsl_multiroot_fsolver_type *T;
  gsl_multiroot_fsolver *s;
  
  int estado = 0, estadoInt, k, longitud ;
  int nvar  = [variables count] ;
  double par;
  NSString *mensaje ;
  size_t iter ;
  
  const size_t n = nvar;
  struct parametros p = {1.0, 1.0};
  
  int countRes = 0 ;
  id unObj ;
  NSMutableArray *resultados = [NSMutableArray array] ;
  NSEnumerator *varCount ;
  
  id datoSigno ;
  NSNumber *tipoOtro ;
  NSMutableArray *verifSigno ;
  NSEnumerator *signoObj ;
  
  gsl_vector *x = gsl_vector_alloc (n);
  
  //Generador de numeros aleatorios
  const gsl_rng_type * Y;
  gsl_rng * r;
  gsl_multiroot_function f;
  gsl_rng_env_setup();
  Y = gsl_rng_default;
  r = gsl_rng_alloc (Y);
  
  do
    {
      iter = 0 ;
      for (k = 0; k < nvar; k++)
	{
	  if( aumento <= 30 )
	    {
	      nuevoValor = 100 ;
	    }
	  else
	    {
	      nuevoValor = 1000 ;
	    }
	  
	  par = nuevoValor*(gsl_rng_uniform (r)) ;
	  gsl_vector_set (x, k, par) ;
	}
      
      f.f = &sis_estatica;
      f.n = n;
      f.params = &p;   
      T = gsl_multiroot_fsolver_hybrids;
      s = gsl_multiroot_fsolver_alloc (T, nvar);
      gsl_multiroot_fsolver_set (s, &f, x);
      
      do
	{
	  iter++;
	  estadoInt = gsl_multiroot_fsolver_iterate (s);
	  
	  if(estadoInt)
	    break;
	  
	  estado = gsl_multiroot_test_residual (s->f, 1e-7);
	}
      while (estado == GSL_CONTINUE && iter < 1000);  
      
      //Se verifica el estado
      if( (estadoInt) && (aumento < 60) )
	{
	  aumento = aumento + 1 ;
	  continuar = YES ;
	}
      else
	{
	  continuar = NO ;
	}
      //Se termina la verificacion
    }
  while(continuar) ;
  //se termino la busqueda de la solucion
  
  //Se pasan los datos al array Resultados
  varCount = [variables objectEnumerator] ;
  
  while((unObj = [varCount nextObject]))
    {
      [resultados addObject: [NSNumber numberWithDouble: gsl_vector_get (s->x, countRes)] ] ;
      countRes = countRes + 1 ;
    }
  
  //Se corrigen signos en los datos
  signoObj = [diccionario objectEnumerator] ;
  
  int par1, w, g, signo;
  double nv, nf;
  while((datoSigno = [signoObj nextObject]))
    {
      par1 = 0;
      w = 0;
      g = 0;
      signo = 1;
      nv = 0;
      nf = 0;

      tipoOtro = [datoSigno objectForKey: @"Tipo"] ;
      
      switch([tipoOtro intValue])
	{
	case 52 ... 53:
	  {
	    verifSigno = [datoSigno objectForKey: @"Valores"] ;
	    
	    //Verify the angle of the plane
	    if([variables containsObject: [[verifSigno objectAtIndex: 1] stringByTrimmingSpaces]])
	      {
		w = [variables indexOfObject: [[verifSigno objectAtIndex: 1] stringByTrimmingSpaces]] ;
		nv = [[resultados objectAtIndex: w] doubleValue] ;
		
                if( nv > 180 )
		  {
		    nv = nv - floor(nv/180)*180 ;
		  }
                
                if( nv < 0 )
		  {
		    nv = nv + (floor(-1*nv/180) + 1)*180 ;                
		  }

                [resultados replaceObjectAtIndex: w withObject: [NSNumber numberWithDouble: nv]] ;
	      }
	  }
	  break;
	case 56 ... 59:
	  {
	    verifSigno = [datoSigno objectForKey: @"Valores"] ;
	    
	    //Verify the force
	    if( ([variables containsObject: [[verifSigno objectAtIndex: 0] stringByTrimmingSpaces]]) &&
		([variables containsObject: [[verifSigno objectAtIndex: 1] stringByTrimmingSpaces]]) )
	      {
		g = [variables indexOfObject: [[verifSigno objectAtIndex: 0] stringByTrimmingSpaces]];
		nf = [[resultados objectAtIndex: g] doubleValue];

		w = [variables indexOfObject: [[verifSigno objectAtIndex: 1] stringByTrimmingSpaces]];
		nv = [[resultados objectAtIndex: w] doubleValue];
		
		if( nv > 360 )
		  {
		    nv = nv - floor(nv/360)*360 ;
		  }
                
                if( nv < 0 )
		  {
		    nv = nv + (floor(-1*nv/360) + 1)*360 ;                
		  }

		if ( (nv > 180) && (nv < 270) )
		  {
		    signo = -1;
		    nv = nv - 180;
		  }

		[resultados replaceObjectAtIndex: g withObject: [NSNumber numberWithDouble: signo*nf]];
		[resultados replaceObjectAtIndex: w withObject: [NSNumber numberWithDouble: nv]];
	      }
	    else if ([variables containsObject: [[verifSigno objectAtIndex: 1] stringByTrimmingSpaces]])
	      {
		w = [variables indexOfObject: [[verifSigno objectAtIndex: 1] stringByTrimmingSpaces]] ;
		nv = [[resultados objectAtIndex: w] doubleValue] ;
		
                if( nv > 360 )
		  {
		    nv = nv - floor(nv/360)*360 ;
		  }
                
                if( nv < 0 )
		  {
		    nv = nv + (floor(-1*nv/360) + 1)*360 ;                
		  }
                
                [resultados replaceObjectAtIndex: w withObject: [NSNumber numberWithDouble: nv]] ;
	      }
	  }
	  break;
	case 72:
	  {
	    verifSigno = [datoSigno objectForKey: @"Valores"] ;
	    
	    //Verify the resultant
	    if( ([variables containsObject: [[verifSigno objectAtIndex: 0] stringByTrimmingSpaces]]) &&
		([variables containsObject: [[verifSigno objectAtIndex: 1] stringByTrimmingSpaces]]) )
	      {
		g = [variables indexOfObject: [[verifSigno objectAtIndex: 0] stringByTrimmingSpaces]] ;
		
		if ( [[resultados objectAtIndex: g] doubleValue] < 0 )
		  {
		    nf = -1*[[resultados objectAtIndex: g] doubleValue];
		    [resultados replaceObjectAtIndex: g withObject: [NSNumber numberWithDouble: nf]];
		    par1 = 1;
		  }

		w = [variables indexOfObject: [[verifSigno objectAtIndex: 1] stringByTrimmingSpaces]];
		nv = [[resultados objectAtIndex: w] doubleValue];
		
                if ( par1 == 1 )
		  {
		    nv = nv + 180;
		  }
		
                if ( nv > 360 )
		  {
		    nv = nv - floor(nv/360)*360;
		  }
		
                if ( nv < 0 )
		  {
		    nv = nv + (floor(-1*nv/360) + 1)*360;
		  }
		
                [resultados replaceObjectAtIndex: w withObject: [NSNumber numberWithDouble: nv]];
	      }
	    else if ([variables containsObject: [[verifSigno objectAtIndex: 1] stringByTrimmingSpaces]])
	      {
		w = [variables indexOfObject: [[verifSigno objectAtIndex: 1] stringByTrimmingSpaces]] ;
		nv = [[resultados objectAtIndex: w] doubleValue] ;
		
                if( nv > 360 )
		  {
		    nv = nv - floor(nv/360)*360 ;
		  }
                
                if( nv < 0 )
		  {
		    nv = nv + (floor(-1*nv/360) + 1)*360 ;                
		  }
                
                [resultados replaceObjectAtIndex: w withObject: [NSNumber numberWithDouble: nv]] ;
	      }
	  }
	  break;
	}
    } 
  
  //Se imprimen los resultados
  [self printUnknowns: variables withResults: resultados];
  
  //Se imprime el estado del calculo        
  mensaje = [NSString stringWithFormat: [errores objectAtIndex: 6], gsl_strerror (estado)];
  longitud = [[[self visor] textStorage] length];
  [[self visor] replaceCharactersInRange:NSMakeRange(longitud,0)withString: mensaje] ;
  
  gsl_multiroot_fsolver_free (s);
  gsl_vector_free (x);
  gsl_rng_free (r);
}
@end

@implementation estaticaPuntual

- (id) init
{
  NSBundle *mensajes;
  self = [super init];
  
  variables = [NSMutableArray array] ;
  [variables retain] ;
  codObjetos = [NSMutableArray array] ;
  [codObjetos retain] ;
  codOtros = [NSMutableArray array] ;
  [codOtros retain] ;
  fuerObj = [NSMutableArray array] ;
  [fuerObj retain] ;
  tipoFuer = [NSMutableArray array] ;
  [tipoFuer retain] ;
  
  //Se crea el array de mensajes
  mensajes = [NSBundle mainBundle] ;
  errores = [[NSArray alloc] initWithContentsOfFile: [mensajes pathForResource: @"estaticaMensajes" ofType: @"plist"] ] ;
  
  return self;
}

- (void) crearEcuaciones: (NSMutableDictionary *)lista
{
  /* insert your code here */
  int width, height, totalCells; //For handle the chalkboard size
  int longitud, numEcuaciones = 0, numFuerzas = 0 ;
  NSUInteger sistema = [self system];
  BOOL error = NO;
  BOOL errorFuer = NO;
  BOOL errorAngles = NO;
  NSNumber *identificador, *codigo ;
  //NSString *mensaje ;
  NSMutableArray *codFuerzas = [NSMutableArray array] ;
  NSMutableArray *codFuerzasObj = [NSMutableArray array] ;
  NSArray *keys;
  NSEnumerator *cuenta;
  NSTextView *estaticaPuntInfo = [self visor];
  NSArray *ordenObjetos = [self cells];
  //Para determinar las fuerzas que actuan en los objetos
  int k ; 
  NSButton *celda ;
  
  varG = 0 ;
  gravedadDat = 0 ;

  //For handle the chalkboard size
  width = [self chalkboardWidth];
  height = [self chalkboardHeight];
  totalCells = width*height - 1;
    
  diccionario = [[NSMutableDictionary alloc] initWithDictionary: lista] ;
  keys = [[NSArray alloc] initWithArray: [lista allKeys]] ;
  cuenta = [keys objectEnumerator] ;
  
  while((codigo = [cuenta nextObject])) 
    {
      int x ;
      NSString *key ;
      NSArray *terminos ;
      NSNumber *numero ;
      NSArray *titulos = [[diccionario objectForKey: codigo] objectForKey: @"Titulos"] ;
      NSMutableArray *datos = [[diccionario objectForKey: codigo] objectForKey: @"Datos"] ;
      NSMutableArray *valores = [[diccionario objectForKey: codigo] objectForKey: @"Valores"] ;

      //Para las fuerzas
      int pos ;
      NSNumber *ident ;
      NSEnumerator *busq;
      //fin de variables para las fuerzas
      identificador = [[diccionario objectForKey: codigo] objectForKey: @"Tipo"] ;
      [valores removeAllObjects] ;
      
      //Cuenta la cantidad de variables en el sistema
      for(x = 0; x < [datos count]; x++)
	{
	  NSString *data = [[datos objectAtIndex: x] stringByTrimmingSpaces];
	  
	  if(![self isNumericDataTheString: data] &&
	     ![[[titulos objectAtIndex: x] description] isEqualToString: _(@"Nombre")])
	    {
	      if([self hasConversionTheString: data])
		{
		  terminos = [[datos objectAtIndex: x] componentsSeparatedByString: @"@"] ;
		  key = [[terminos objectAtIndex: 1] stringByTrimmingSpaces] ;
                  
		  if([[[self conversions] allKeys] containsObject: key])
		    {
		      
		      if([self isNumericDataTheString: [[terminos objectAtIndex: 0] stringByTrimmingSpaces]])
                        {
			  numero = [NSNumber numberWithDouble: [[terminos objectAtIndex: 0] doubleValue]*[[[self conversions] objectForKey: key] doubleValue] ] ;
			  [valores addObject: [numero stringValue]] ;
                        }
		      else
                        {
			  NSString *var = [[terminos objectAtIndex: 0] stringByTrimmingSpaces] ;
			  var = [var stringByAppendingString: @"@"] ;
			  var = [var stringByAppendingString: [[terminos objectAtIndex: 1] stringByTrimmingSpaces]] ;
			  
			  [valores addObject: var] ;
			  if(![variables containsObject: var])
			    {
			      [variables addObject: var] ;
			    }
			  
                        }
		    }
		  else
		    {
                      NSString *anuncio = [NSString stringWithFormat: [errores objectAtIndex: 0], [key cString]] ;
                      longitud = [[[self visor] textStorage] length];
                      [[self visor] replaceCharactersInRange:NSMakeRange(longitud,0)withString: anuncio] ;
                      error = YES ;
		    }
		  
		}
	      else
		{
		  //Se agrega una variable simple 
		  NSString *varTit, *varFactor ;   
		  NSString *var = [[datos objectAtIndex: x] stringByTrimmingSpaces] ;
		  
		  //Se determina el tipo de variable
		  varTit = [[titulos objectAtIndex: x] stringByTrimmingSpaces] ;
		  
		  if ([varTit hasPrefix: @"m"])
		    {
		      if (sistema== 0)
			{ varFactor = [NSString stringWithString: @"kg"] ; }
		      else
			{ varFactor = [NSString stringWithString: @"slug"] ; } 
		    }
		  else if ([varTit hasPrefix: @"f"] || [varTit hasPrefix: @"N"])
		    {
		      if (sistema== 0)
			{ varFactor = [NSString stringWithString: @"N"] ; }
		      else
			{ varFactor = [NSString stringWithString: @"lb"] ; }
		    }
		  else if ([varTit hasPrefix: @"ang"])
		    {
		      varFactor = [NSString stringWithString: _(@"grados")] ;
		    }
		  else if ([varTit hasPrefix: @"g"])
		    {
		      if (sistema== 0)
			{ varFactor = [NSString stringWithString: @"m/s2"] ; }
		      else
			{ varFactor = [NSString stringWithString: @"ft/s2"] ; }
		    }
		  else if ([varTit hasPrefix: @"d"])
		    {
		      if (sistema== 0)
			{ varFactor = [NSString stringWithString: @"m"] ; }
		      else
			{ varFactor = [NSString stringWithString: @"ft"] ; }
		    }
		  else if ([varTit hasPrefix: @"k"])
		    {
		      if (sistema== 0)
			{ varFactor = [NSString stringWithString: @"N/m"] ; }
		      else
			{ varFactor = [NSString stringWithString: @"lb/ft"] ; }
		    }
		  else
		    {
		      varFactor = [NSString stringWithString: @"ad"] ; 
		    }
		  //Termina la busqueda del tipo de variable
		  
		  var = [var stringByAppendingString: @"@"] ;
		  var = [var stringByAppendingString: varFactor] ;
		  
		  [valores addObject: var] ;
		  if(![variables containsObject: var])
		    {
		      [variables addObject: var] ;
		    }
		  
		  //Se ha agregado la variable simple   
		}
	    }
          else
	    {
	      [valores addObject: [datos objectAtIndex: x]] ;
	    }
	}    
      //Fin del conteo de variables
      
      if(error)
	break ;
      
      //Determina la variable de la gravedad y el numero de ecuaciones
      switch ([identificador intValue])
	{
	case 50:
	  {
	    if(![self isNumericDataTheString: [[valores objectAtIndex: 0] stringByTrimmingSpaces]])
	      {
		gravedadVar = [[valores objectAtIndex: 0] stringByTrimmingSpaces];
		varG = 1 ;
	      }
	    else
	      {
		gravedadDat = [[valores objectAtIndex: 0] doubleValue];
		varG = 2 ;
	      }
	  }
	  break;
	case 51:
	  {
	    numEcuaciones = numEcuaciones + 2;
	    [codObjetos addObject: codigo] ;
	  }    
	  break;
	case 52:
	  {
	    numEcuaciones = numEcuaciones + 2;
	    [codObjetos addObject: codigo] ;
	  }
	  break;
	case 53:
	  {
	    numEcuaciones = numEcuaciones + 2;
	    [codObjetos addObject: codigo] ;
	  }
	  break;
	case 54:
	  {
	    numEcuaciones = numEcuaciones + 2;
	    [codObjetos addObject: codigo] ;
	  }
	  break;
	case 55:
	  {
	    numEcuaciones = numEcuaciones + 2;
	    [codObjetos addObject: codigo] ;
	  }
	  break;
	case 56 ... 74:
	  {
	    numFuerzas = numFuerzas + 1 ;
	    [codFuerzas addObject: codigo] ;
	  }
	  break;
	case 75 ... 78:
	  {
	    numEcuaciones = numEcuaciones + 1;
	    [codObjetos addObject: codigo] ;
	  }
	  break;
	case 79:
	  {
	    if (![self isNumericDataTheString: [[valores objectAtIndex: 0] stringByTrimmingSpaces]] &&
		![self isNumericDataTheString: [[valores objectAtIndex: 1] stringByTrimmingSpaces]])
	      {
		numEcuaciones = numEcuaciones + 1;
		[codOtros addObject: codigo];
	      }
	    else
	      {
		errorAngles = YES;
	      }
	  }
	  break;
	}
      //Fin del conteo de ecuaciones

      if (errorAngles)
	break;
      
      //Se determinan las fuerzas que actuan en cada objeto
      busq = [ordenObjetos objectEnumerator] ;
      
      if( ([identificador intValue] >= 51) && ([identificador intValue] <= 55) )
	{
	  NSMutableArray *fuerzas = [NSMutableArray array] ;
	  int fuerHoriz = 0, fuerVert = 0 ;   
	  NSNumber *fuerTipo ;  
	  NSEnumerator *verif ;
	  k = 0 ;
	  pos = 0 ;
	  
	  while((celda = [busq nextObject]))
	    {
	      if([celda tag] == [codigo intValue])
		{
		  pos = k ;
		  break ;
		}
	      k = k + 1 ;   
	    }
	  
	  
	  if( (pos%width != 0) && (pos%width != (width - 1)) )
	    {
	      if(pos - 1 >= 0)
		{
		  ident = [NSNumber numberWithInt: [[ordenObjetos objectAtIndex: pos - 1] tag]] ;
		  if([ident intValue] != 0)
		    { [fuerzas addObject: ident] ; }
		}
	      
	      if(pos - (width - 1) >= 0)
		{
		  ident = [NSNumber numberWithInt: [[ordenObjetos objectAtIndex: pos - (width - 1)] tag]] ;
		  if([ident intValue] != 0)
		    { [fuerzas addObject: ident] ; }
		}
	      
	      if(pos - width >= 0)
		{
		  ident = [NSNumber numberWithInt: [[ordenObjetos objectAtIndex: pos - width] tag]] ;
		  if([ident intValue] != 0)
		    { [fuerzas addObject: ident] ; }
		}
	      
	      if(pos - (width + 1) >= 0)
		{
		  ident = [NSNumber numberWithInt: [[ordenObjetos objectAtIndex: pos - (width + 1)] tag]] ;
		  if([ident intValue] != 0)
		    { [fuerzas addObject: ident] ; }
		}
	      
	      if(pos + 1 <= totalCells)
		{
		  ident = [NSNumber numberWithInt: [[ordenObjetos objectAtIndex: pos + 1] tag]] ;
		  if([ident intValue] != 0)
		    { [fuerzas addObject: ident] ; }
		}
	      
	      if(pos + (width - 1) <= totalCells)
		{
		  ident = [NSNumber numberWithInt: [[ordenObjetos objectAtIndex: pos + (width - 1)] tag]] ;
		  if([ident intValue] != 0)
		    { [fuerzas addObject: ident] ; }
		}
	      
	      if(pos + width <= totalCells)
		{
		  ident = [NSNumber numberWithInt: [[ordenObjetos objectAtIndex: pos + width] tag]] ;
		  if([ident intValue] != 0)
		    { [fuerzas addObject: ident] ; }
		}
	      
	      if(pos + (width + 1) <= totalCells)
		{
		  ident = [NSNumber numberWithInt: [[ordenObjetos objectAtIndex: pos + (width + 1)] tag]] ;
		  if([ident intValue] != 0)
		    { [fuerzas addObject: ident] ; }
		}
	    }
	  else
	    {
	      if(pos%width == 0)
		{
		  if(pos - (width - 1) >= 0)
		    {
		      ident = [NSNumber numberWithInt: [[ordenObjetos objectAtIndex: pos - (width - 1)] tag]] ;
		      if([ident intValue] != 0)
			{ [fuerzas addObject: ident] ; }
		    }
		  
		  if(pos - width >= 0)
		    {
		      ident = [NSNumber numberWithInt: [[ordenObjetos objectAtIndex: pos - width] tag]] ;
		      if([ident intValue] != 0)
			{ [fuerzas addObject: ident] ; }
		    }
		  
		  if(pos + 1 <= totalCells)
		    {
		      ident = [NSNumber numberWithInt: [[ordenObjetos objectAtIndex: pos + 1] tag]] ;
		      if([ident intValue] != 0)
			{ [fuerzas addObject: ident] ; }
		    }
		  
		  if(pos + width <= totalCells)
		    {
		      ident = [NSNumber numberWithInt: [[ordenObjetos objectAtIndex: pos + width] tag]] ;
		      if([ident intValue] != 0)
			{ [fuerzas addObject: ident] ; }
		    }
		  
		  if(pos + (width + 1) <= totalCells)
		    {
		      ident = [NSNumber numberWithInt: [[ordenObjetos objectAtIndex: pos + (width + 1)] tag]] ;
		      if([ident intValue] != 0)
			{ [fuerzas addObject: ident] ; }
		    }
		}
	      else
		{
		  if(pos - 1 >= 0)
		    {
		      ident = [NSNumber numberWithInt: [[ordenObjetos objectAtIndex: pos - 1] tag]] ;
		      if([ident intValue] != 0)
			{ [fuerzas addObject: ident] ; }
		    }
		  
		  if(pos - width >= 0)
		    {
		      ident = [NSNumber numberWithInt: [[ordenObjetos objectAtIndex: pos - width] tag]] ;
		      if([ident intValue] != 0)
			{ [fuerzas addObject: ident] ; }
		    }
		  
		  if(pos - (width + 1) >= 0)
		    {
		      ident = [NSNumber numberWithInt: [[ordenObjetos objectAtIndex: pos - (width + 1)] tag]] ;
		      if([ident intValue] != 0)
			{ [fuerzas addObject: ident] ; }
		    }
		  
		  if(pos + (width - 1) <= totalCells)
		    {
		      ident = [NSNumber numberWithInt: [[ordenObjetos objectAtIndex: pos + (width - 1)] tag]] ;
		      if([ident intValue] != 0)
			{ [fuerzas addObject: ident] ; }
		    }
		  
		  if(pos + width <= totalCells)
		    {
		      ident = [NSNumber numberWithInt: [[ordenObjetos objectAtIndex: pos + width] tag]] ;
		      if([ident intValue] != 0)
			{ [fuerzas addObject: ident] ; }
		    }
		}
	    }
	  
	  //Se determina el tipo de fuerzas aplicadas al objeto y se corrige el numero de ecuaciones
	  if( ([identificador intValue] == 52) && ([fuerzas count] > 0) )
	    {
	      [tipoFuer addObject: [NSNumber numberWithInt: 1]] ;
	      
	      verif = [fuerzas objectEnumerator] ;
              while((fuerTipo = [verif nextObject]))
		{
		  int t = [[[diccionario objectForKey: fuerTipo] objectForKey: @"Tipo"] intValue] ;
		  if( (t >= 66) || ((t >= 50) && (t <= 55)))
		    {
		      errorFuer = YES ;
		    } 
		  
		}
	    }
	  
	  if( ([identificador intValue] == 53) && ([fuerzas count] > 0) )
	    {
	      [tipoFuer addObject: [NSNumber numberWithInt: 1]] ;
	      
	      verif = [fuerzas objectEnumerator] ;
              while((fuerTipo = [verif nextObject]))
		{
		  int t = [[[diccionario objectForKey: fuerTipo] objectForKey: @"Tipo"] intValue] ;
		  if( (t == 64) || (t == 65) || (t >= 68) || ((t >= 50) && (t <= 55)))
		    {
		      errorFuer = YES ;
		    } 
		  
		}
	    }
	  
	  if( ([identificador intValue] == 54) && ([fuerzas count] > 0) )
	    {
	      verif = [fuerzas objectEnumerator] ;
              while((fuerTipo = [verif nextObject]))
		{
		  int t = [[[diccionario objectForKey: fuerTipo] objectForKey: @"Tipo"] intValue] ;
		  if( (t == 60) || (t == 61) )
		    {
		      fuerHoriz = fuerHoriz + 1 ;
		    }
		  
		  if( (t == 62) || (t == 63) )
		    {
		      fuerVert = fuerVert + 1 ;
		    }
		  
		  if( (t >= 64) || (t <= 55) || ((t >= 50) && (t <= 55)))
		    {
		      errorFuer = YES ;
		    } 
		  
		}
              
              if([fuerzas count] == fuerHoriz)
		{
		  numEcuaciones = numEcuaciones - 1;
		  [tipoFuer addObject: [NSNumber numberWithInt: 2]] ;
		}
              else
		{
                  if([fuerzas count] == fuerVert)
		    {
		      numEcuaciones = numEcuaciones - 1;
		      [tipoFuer addObject: [NSNumber numberWithInt: 3]] ;
		    }
                  else
		    {
		      [tipoFuer addObject: [NSNumber numberWithInt: 1]] ;
		    }
		}
              
	    }
	  
	  if( ([identificador intValue] == 55) && ([fuerzas count] > 0) )
	    {
	      verif = [fuerzas objectEnumerator] ;
              while((fuerTipo = [verif nextObject]))
		{
		  int t = [[[diccionario objectForKey: fuerTipo] objectForKey: @"Tipo"] intValue] ;
		  if( (t == 60) || (t == 61) || (t == 73) )
		    {
		      fuerHoriz = fuerHoriz + 1 ;
		    }
		  
		  if( (t == 62) || (t == 63) || (t == 74) )
		    {
		      fuerVert = fuerVert + 1 ;
		    }
		  
		  if( ((t >= 64) && (t <= 71)) || ((t >= 50) && (t <= 55)) )
		    {
		      errorFuer = YES ;
		    }
		  
		}
              
              if([fuerzas count] == fuerHoriz)
		{
		  numEcuaciones = numEcuaciones - 1;
		  [tipoFuer addObject: [NSNumber numberWithInt: 2]] ;
		}
              else
		{
                  if([fuerzas count] == fuerVert)
		    {
		      numEcuaciones = numEcuaciones - 1;
		      [tipoFuer addObject: [NSNumber numberWithInt: 3]] ;
		    }
                  else
		    {
		      [tipoFuer addObject: [NSNumber numberWithInt: 1]] ;
		    }
		}
              
	    }
          
	  if( ([identificador intValue] == 51) && ([fuerzas count] > 0) )
	    {
	      verif = [fuerzas objectEnumerator] ;
              while((fuerTipo = [verif nextObject]))
		{
		  int t = [[[diccionario objectForKey: fuerTipo] objectForKey: @"Tipo"] intValue] ;
		  if( (t == 62) || (t == 63) )
		    {
		      fuerVert = fuerVert + 1 ;
		    }
		  
		  if( ((t >= 64) && (t <= 67)) || (t >= 72) || ((t >= 50) && (t <= 55)) )
		    {
		      errorFuer = YES ;
		    }
		  
		}
	      
              if([fuerzas count] == fuerVert)
		{
		  numEcuaciones = numEcuaciones - 1;
		  [tipoFuer addObject: [NSNumber numberWithInt: 3]] ;
		}
              else
		{
		  [tipoFuer addObject: [NSNumber numberWithInt: 1]] ;
		}
              
	    }
	  
	  if([fuerzas count] > 0)
	    {
	      [fuerObj addObject: fuerzas] ; 
	    }       
	}
      else
	{
	  int signo = 0 ;
	  NSMutableArray *fuerzas = [NSMutableArray array] ;
	  
	  if(([identificador intValue] >= 75) && ([identificador intValue] <= 78))
	    {
	      int rFuer = 0 ;
	      k = 0 ;
	      pos = 0 ;
	      
	      while((celda = [busq nextObject]))
		{
		  if([celda tag] == [codigo intValue])
		    {
		      pos = k ;
		      break ;
		    }
		  k = k + 1 ;   
		}
	      
	      if([identificador intValue] == 75)
		{
		  rFuer = width - 1 ;
		}
	      else
		{ 
		  if([identificador intValue] == 76)
		    {
		      rFuer = width + 1 ;
		    }
		  else
		    {
		      if([identificador intValue] == 77)
			{
			  rFuer = width ;
			}
		      else
			{
			  rFuer = 1 ;
			}
		    }
		}             
	      
              if( (pos%width != 0) && (pos%width != (width - 1)) )
                {
		  if(pos - rFuer >= 0)
                    {
		      ident = [NSNumber numberWithInt: [[ordenObjetos objectAtIndex: pos - rFuer] tag]] ;
		      if([ident intValue] != 0)
			{ [fuerzas addObject: ident] ; 
			  signo = 1; }
                    }
		  
		  if(pos + rFuer <= totalCells)
                    {
		      ident = [NSNumber numberWithInt: [[ordenObjetos objectAtIndex: pos + rFuer] tag]] ;
		      if([ident intValue] != 0)
			{ [fuerzas addObject: ident] ; 
			  signo = -1; }
                    }
                }
              else
                {
		  if(pos%width == 0)
		    { 
		      if((pos - rFuer >= 0) && ((rFuer != 1) || (rFuer != (width + 1)))) 
			{
			  ident = [NSNumber numberWithInt: [[ordenObjetos objectAtIndex: pos - rFuer] tag]] ;
			  if([ident intValue] != 0)
			    { [fuerzas addObject: ident] ; 
			      signo = 1; }
			}
		      
		      if((pos + rFuer <= totalCells) && (rFuer != (width - 1)))
			{
			  ident = [NSNumber numberWithInt: [[ordenObjetos objectAtIndex: pos + rFuer] tag]] ;
			  if([ident intValue] != 0)
			    { [fuerzas addObject: ident] ; 
			      signo = -1 ;}
			}
		    }
		  else
		    {
		      if((pos - rFuer >= 0) && (rFuer != (width - 1))) 
			{
			  ident = [NSNumber numberWithInt: [[ordenObjetos objectAtIndex: pos - rFuer] tag]] ;
			  if([ident intValue] != 0)
			    { [fuerzas addObject: ident] ; 
			      signo = 1; }
			}
		      
		      if((pos + rFuer <= totalCells) && ((rFuer != 1) || (rFuer != (width + 1))))
			{
			  ident = [NSNumber numberWithInt: [[ordenObjetos objectAtIndex: pos + rFuer] tag]] ;
			  if([ident intValue] != 0)
			    { [fuerzas addObject: ident] ; 
			      signo = -1; }
			}
		    }
                } 
	    }
	  
	  //Verificacion de fuerzas
	  if([fuerzas count] > 0)
	    {
	      int f1, f2;
	      
              if(signo > 0) 
		{
		  [tipoFuer addObject: [NSNumber numberWithInt: 4]] ;
		}
              else
		{
		  if([fuerzas count] == 1)
		    {
		      [tipoFuer addObject: [NSNumber numberWithInt: 5]] ;
		    }
		  else
		    {
		      [tipoFuer addObject: [NSNumber numberWithInt: 4]] ;
		    }
		}
	      
	      //Se verifica el tipo de fuerza aplicada al resorte
	      f1 = [[[diccionario objectForKey: [fuerzas objectAtIndex: 0]] objectForKey: @"Tipo"] intValue] ;
	      if (([identificador intValue] == 75) && (f1 != 56) && (f1 != 57))
		{
		  errorFuer = YES;
		}
	      
	      if (([identificador intValue] == 76) && (f1 != 58) && (f1 != 59))
		{
		  errorFuer = YES;
		}
	      
	      if (([identificador intValue] == 77) && (f1 != 62) && (f1 != 63))
		{
		  errorFuer = YES;
		}
	      
	      if (([identificador intValue] == 78) && (f1 != 60) && (f1 != 61))
		{
		  errorFuer = YES;
		}
              
	      
	      //Se verifican las fuerzas aplicadas (para el caso cuando hay dos fuerzas)
              if([fuerzas count] > 1)
		{
		  f2 = [[[diccionario objectForKey: [fuerzas objectAtIndex: 1]] objectForKey: @"Tipo"] intValue] ;
		  
		  if (([identificador intValue] == 75) && (f2 != 56) && (f2 != 57))
		    {
		      errorFuer = YES;
		    }
		  
		  if (([identificador intValue] == 76) && (f2 != 58) && (f2 != 59))
		    {
		      errorFuer = YES;
		    }
		  
		  if (([identificador intValue] == 77) && (f2 != 62) && (f2 != 63))
		    {
		      errorFuer = YES;
		    }
		  
		  if (([identificador intValue] == 78) && (f2 != 60) && (f2 != 61))
		    {
		      errorFuer = YES;
		    }
		  
		  if(f1 == f2)
		    {
		      errorFuer = YES ;
		    }
		}
	    }
	  
	  if([fuerzas count] > 0)
	    {
	      [fuerObj addObject: fuerzas] ; 
	    }     
	}
    }
  
  //longitud = [ [estaticaPuntInfo textStorage] length];
  //[estaticaPuntInfo replaceCharactersInRange:NSMakeRange(longitud,0)withString: [[tipoFuer objectAtIndex: 0] description] ] ;    
  
  //Se verifica que todos los objetos tengan fuerzas aplicadas
  if( ([codObjetos count] == [fuerObj count]) && !error && !errorFuer && !errorAngles)
    {
      //Se realiza el conteo de las fuerzas aplicadas 
      int v ;
      int w = 0 ;
      NSEnumerator *compro;
      NSNumber *fuer ;
      for(v = 0; v < [codObjetos count]; v++)
	{
	  //mensaje = [NSString stringWithFormat: @"\n Objeto: %d  fuerzas: %d \n", [[codObjetos objectAtIndex: v] intValue], [[fuerObj objectAtIndex: v] count] ];
	  //longitud = [ [estaticaPuntInfo textStorage] length];
	  //[estaticaPuntInfo replaceCharactersInRange:NSMakeRange(longitud,0)withString: mensaje] ;
	  
	  [codFuerzasObj addObjectsFromArray: [fuerObj objectAtIndex: v]] ;  
	}
      
      //Se verifica cuantas de las fuerzas existentes estan aplicadas a objetos
      compro = [codFuerzas objectEnumerator] ;
      
      while((fuer = [compro nextObject]))
	{
	  if([codFuerzasObj containsObject: fuer])
	    {
	      w = w + 1 ;
	    }
	  
	  //longitud = [ [estaticaPuntInfo textStorage] length];
	  //[estaticaPuntInfo replaceCharactersInRange:NSMakeRange(longitud,0)withString: @"\n"] ;  
	  //longitud = [ [estaticaPuntInfo textStorage] length];
	  //[estaticaPuntInfo replaceCharactersInRange:NSMakeRange(longitud,0)withString: [fuer description]] ; 
	}
      
      /*
	longitud = [ [estaticaPuntInfo textStorage] length];
	[estaticaPuntInfo replaceCharactersInRange:NSMakeRange(longitud,0)withString: [codFuerzasObj componentsJoinedByString: @"-"]] ;
	mensaje = [NSString stringWithFormat: @"\n Total fuerzas: %d  fuerzas en objetos: %d \n", w, [codFuerzasObj count] ];
	longitud = [ [estaticaPuntInfo textStorage] length];
	[estaticaPuntInfo replaceCharactersInRange:NSMakeRange(longitud,0)withString: mensaje] ;
	longitud = [ [estaticaPuntInfo textStorage] length];
      */
      
      
      //Ultimas verificaciones        
      if(([variables count] == numEcuaciones) && (numEcuaciones > 0))
	{
	  if( (w == [codFuerzas count]) && (w == [codFuerzasObj count]) )
	    {
	      [self crearSistema] ;
	    }
	  else
	    {
	      NSString *advertencia = nil;
	      
	      if(w < [codFuerzas count])
		{
		  advertencia = [NSString stringWithString: [errores objectAtIndex: 1]] ;
		}
	      
	      if(w < [codFuerzasObj count])
		{
		  advertencia = [NSString stringWithString: [errores objectAtIndex: 2]] ;
		}
	      
	      longitud = [ [estaticaPuntInfo textStorage] length];
	      [estaticaPuntInfo replaceCharactersInRange:NSMakeRange(longitud,0)withString: advertencia] ;
	    }
	}
      else
	{
	  longitud = [ [estaticaPuntInfo textStorage] length];
	  [estaticaPuntInfo replaceCharactersInRange:NSMakeRange(longitud,0)withString: [errores objectAtIndex: 3]] ;        
	}
    }
  else
    {
      if (errorFuer)
	{
	  longitud = [ [estaticaPuntInfo textStorage] length];
	  [estaticaPuntInfo replaceCharactersInRange:NSMakeRange(longitud,0)withString: [errores objectAtIndex: 5]] ;
	}
      else if (errorAngles)
	{
	  longitud = [ [estaticaPuntInfo textStorage] length];
	  [estaticaPuntInfo replaceCharactersInRange:NSMakeRange(longitud,0)withString: [errores objectAtIndex: 7]] ;
	}
      else if([codObjetos count] != [fuerObj count])
	{
	  longitud = [ [estaticaPuntInfo textStorage] length];
	  [estaticaPuntInfo replaceCharactersInRange:NSMakeRange(longitud,0)withString: [errores objectAtIndex: 4]] ;
	}
    }
  
  RELEASE(keys) ;
}

- (void) dealloc
{
  RELEASE(diccionario) ;
  RELEASE(variables) ;
  RELEASE(codObjetos) ;
  RELEASE(codOtros);
  RELEASE(fuerObj) ;
  RELEASE(tipoFuer) ;
  RELEASE(errores) ;
  [super dealloc] ;
}

@end
